@@ -138,7 +138,8 @@ func (s *Site) resolveDimensionNames() types.Strings3 {
 }
 
 type siteLanguageVersionRole struct {
-	siteVector sitesmatrix.Vector
+	siteVector        sitesmatrix.Vector
+	isDefaultLanguage bool
 
 	roleInternal roles.RoleInternal
 	role         roles.Role
@@ -186,6 +187,10 @@ func (s siteLanguageVersionRole) Version() versions.Version {
 	return s.version
 }
 
+func (s siteLanguageVersionRole) isDefault() bool {
+	return s.isDefaultLanguage && s.roleInternal.Default && s.versionInternal.Default
+}
+
 func (s *Site) Debug() {
 	fmt.Println("Debugging site", s.Lang(), "=>")
 	// fmt.Println(s.pageMap.testDump())
@@ -341,7 +346,8 @@ func NewHugoSites(cfg deps.DepsCfg) (*HugoSites, error) {
 			frontmatterHandler: frontmatterHandler,
 			store:              hstore.NewScratch(),
 			siteLanguageVersionRole: &siteLanguageVersionRole{
-				siteVector: sitesmatrix.Vector{i, 0, 0},
+				isDefaultLanguage: language.IsDefault(),
+				siteVector:        sitesmatrix.Vector{i, 0, 0},
 			},
 		}
 
@@ -1056,7 +1062,7 @@ func (s *siteRefLinker) refLink(ref string, source any, relative bool, outputFor
 		if outputFormat != "" {
 			o := target.OutputFormats().Get(outputFormat)
 
-			if o == nil {
+			if o.IsZero() {
 				s.logNotFound(refURL.Path, fmt.Sprintf("output format %q", outputFormat), p, pos)
 				return s.notFoundURL, nil
 			}
@@ -1770,10 +1776,6 @@ func (s *Site) render(ctx *siteRenderContext) (err error) {
 		return
 	}
 
-	if err = s.renderMainLanguageRedirect(); err != nil {
-		return
-	}
-
 	return
 }
 
