@@ -575,8 +575,7 @@ func newDispatcher[Q, R any](opts Options) (*dispatcherPool[Q, R], error) {
 	}
 
 	if opts.Memory <= 0 {
-		// 32 MiB
-		opts.Memory = 32
+		opts.Memory = 32 // 32 MiB
 	}
 
 	ctx := opts.Ctx
@@ -793,11 +792,9 @@ func (d *Dispatchers) Webp() (Dispatcher[WebpInput, WebpOutput], error) {
 	return d.webp.start()
 }
 
-func (d *Dispatchers) NewWepCodec(quality int, hint string) (*WebpCodec, error) {
+func (d *Dispatchers) NewWepCodec() (*WebpCodec, error) {
 	return &WebpCodec{
-		d:       d.Webp,
-		quality: quality,
-		hint:    hint,
+		d: d.Webp,
 	}, nil
 }
 
